@@ -1,6 +1,5 @@
 use super::{create_prompt, create_prompt_with_default, Action, OpTrait};
 use crate::{items::TargetData, menu::arg::Arg, state::State, term::Term, Res};
-use derive_more::Display;
 use git2::{Repository, Status, StatusOptions};
 use std::{process::Command, rc::Rc};
 
@@ -11,13 +10,15 @@ pub(crate) fn init_args() -> Vec<Arg> {
     ]
 }
 
-#[derive(Display)]
-#[display(fmt = "both")]
 pub(crate) struct Stash;
 impl OpTrait for Stash {
     fn get_action(&self, _target: Option<&TargetData>) -> Option<Action> {
         Some(create_prompt("Stash message", stash_push, true))
     }
+
+    fn display(&self, _state: &State) -> String {
+        "both".into()
+    }
 }
 
 fn stash_push(state: &mut State, term: &mut Term, input: &str) -> Res<()> {
@@ -33,13 +34,15 @@ fn stash_push(state: &mut State, term: &mut Term, input: &str) -> Res<()> {
     Ok(())
 }
 
-#[derive(Display)]
-#[display(fmt = "index")]
 pub(crate) struct StashIndex;
 impl OpTrait for StashIndex {
     fn get_action(&self, _target: Option<&TargetData>) -> Option<Action> {
         Some(create_prompt("Stash message", stash_push_index, true))
     }
+
+    fn display(&self, _state: &State) -> String {
+        "index".into()
+    }
 }
 
 fn stash_push_index(state: &mut State, term: &mut Term, input: &str) -> Res<()> {
@@ -55,8 +58,6 @@ fn stash_push_index(state: &mut State, term: &mut Term, input: &str) -> Res<()>
     Ok(())
 }
 
-#[derive(Display)]
-#[display(fmt = "worktree")]
 pub(crate) struct StashWorktree;
 impl OpTrait for StashWorktree {
     fn get_action(&self, _target: Option<&TargetData>) -> Option<Action> {
@@ -71,6 +72,10 @@ impl OpTrait for StashWorktree {
             Ok(())
         }))
     }
+
+    fn display(&self, _state: &State) -> String {
+        "worktree".into()
+    }
 }
 
 fn is_working_tree_empty(repo: &Repository) -> Res<bool> {
@@ -140,13 +145,15 @@ fn is_something_staged(repo: &Repository) -> Res<bool> {
     }))
 }
 
-#[derive(Display)]
-#[display(fmt = "keeping index")]
 pub(crate) struct StashKeepIndex;
 impl OpTrait for StashKeepIndex {
     fn get_action(&self, _target: Option<&TargetData>) -> Option<Action> {
         Some(create_prompt("Stash message", stash_push_keep_index, true))
     }
+
+    fn display(&self, _state: &State) -> String {
+        "keeping index".into()
+    }
 }
 
 fn stash_push_keep_index(state: &mut State, term: &mut Term, input: &str) -> Res<()> {
@@ -162,8 +169,6 @@ fn stash_push_keep_index(state: &mut State, term: &mut Term, input: &str) -> Res
     Ok(())
 }
 
-#[derive(Display)]
-#[display(fmt = "pop")]
 pub(crate) struct StashPop;
 impl OpTrait for StashPop {
     fn get_action(&self, _target: Option<&TargetData>) -> Option<Action> {
@@ -174,6 +179,10 @@ impl OpTrait for StashPop {
             true,
         ))
     }
+
+    fn display(&self, _state: &State) -> String {
+        "pop".into()
+    }
 }
 
 fn stash_pop(state: &mut State, term: &mut Term, input: &str) -> Res<()> {
@@ -186,8 +195,6 @@ fn stash_pop(state: &mut State, term: &mut Term, input: &str) -> Res<()> {
     Ok(())
 }
 
-#[derive(Display)]
-#[display(fmt = "apply")]
 pub(crate) struct StashApply;
 impl OpTrait for StashApply {
     fn get_action(&self, _target: Option<&TargetData>) -> Option<Action> {
@@ -198,6 +205,10 @@ impl OpTrait for StashApply {
             true,
         ))
     }
+
+    fn display(&self, _state: &State) -> String {
+        "apply".into()
+    }
 }
 
 fn stash_apply(state: &mut State, term: &mut Term, input: &str) -> Res<()> {
@@ -210,8 +221,6 @@ fn stash_apply(state: &mut State, term: &mut Term, input: &str) -> Res<()> {
     Ok(())
 }
 
-#[derive(Display)]
-#[display(fmt = "drop")]
 pub(crate) struct StashDrop;
 impl OpTrait for StashDrop {
     fn get_action(&self, _target: Option<&TargetData>) -> Option<Action> {
@@ -222,6 +231,10 @@ impl OpTrait for StashDrop {
             true,
         ))
     }
+
+    fn display(&self, _state: &State) -> String {
+        "drop".into()
+    }
 }
 
 fn stash_drop(state: &mut State, term: &mut Term, input: &str) -> Res<()> {
